@@ -6,14 +6,14 @@ Type annotations for redshift-data service type definitions.
 Usage::
 
     ```python
-    from mypy_boto3_redshift_data.type_defs import CancelStatementResponseTypeDef
+    from mypy_boto3_redshift_data.type_defs import CancelStatementRequestTypeDef
 
-    data: CancelStatementResponseTypeDef = {...}
+    data: CancelStatementRequestTypeDef = {...}
     ```
 """
 import sys
 from datetime import datetime
-from typing import IO, Any, Dict, List, Union
+from typing import Any, Dict, List
 
 from .literals import StatusStringType
 
@@ -24,17 +24,26 @@ else:
 
 
 __all__ = (
-    "CancelStatementResponseTypeDef",
+    "CancelStatementRequestTypeDef",
+    "CancelStatementResponseResponseTypeDef",
     "ColumnMetadataTypeDef",
-    "DescribeStatementResponseTypeDef",
-    "DescribeTableResponseTypeDef",
-    "ExecuteStatementOutputTypeDef",
+    "DescribeStatementRequestTypeDef",
+    "DescribeStatementResponseResponseTypeDef",
+    "DescribeTableRequestTypeDef",
+    "DescribeTableResponseResponseTypeDef",
+    "ExecuteStatementInputTypeDef",
+    "ExecuteStatementOutputResponseTypeDef",
     "FieldTypeDef",
-    "GetStatementResultResponseTypeDef",
-    "ListDatabasesResponseTypeDef",
-    "ListSchemasResponseTypeDef",
-    "ListStatementsResponseTypeDef",
-    "ListTablesResponseTypeDef",
+    "GetStatementResultRequestTypeDef",
+    "GetStatementResultResponseResponseTypeDef",
+    "ListDatabasesRequestTypeDef",
+    "ListDatabasesResponseResponseTypeDef",
+    "ListSchemasRequestTypeDef",
+    "ListSchemasResponseResponseTypeDef",
+    "ListStatementsRequestTypeDef",
+    "ListStatementsResponseResponseTypeDef",
+    "ListTablesRequestTypeDef",
+    "ListTablesResponseResponseTypeDef",
     "PaginatorConfigTypeDef",
     "ResponseMetadataTypeDef",
     "SqlParameterTypeDef",
@@ -42,12 +51,19 @@ __all__ = (
     "TableMemberTypeDef",
 )
 
-CancelStatementResponseTypeDef = TypedDict(
-    "CancelStatementResponseTypeDef",
+CancelStatementRequestTypeDef = TypedDict(
+    "CancelStatementRequestTypeDef",
+    {
+        "Id": str,
+    },
+)
+
+CancelStatementResponseResponseTypeDef = TypedDict(
+    "CancelStatementResponseResponseTypeDef",
     {
         "Status": bool,
+        "ResponseMetadata": "ResponseMetadataTypeDef",
     },
-    total=False,
 )
 
 ColumnMetadataTypeDef = TypedDict(
@@ -70,14 +86,15 @@ ColumnMetadataTypeDef = TypedDict(
     total=False,
 )
 
-_RequiredDescribeStatementResponseTypeDef = TypedDict(
-    "_RequiredDescribeStatementResponseTypeDef",
+DescribeStatementRequestTypeDef = TypedDict(
+    "DescribeStatementRequestTypeDef",
     {
         "Id": str,
     },
 )
-_OptionalDescribeStatementResponseTypeDef = TypedDict(
-    "_OptionalDescribeStatementResponseTypeDef",
+
+DescribeStatementResponseResponseTypeDef = TypedDict(
+    "DescribeStatementResponseResponseTypeDef",
     {
         "ClusterIdentifier": str,
         "CreatedAt": datetime,
@@ -86,6 +103,7 @@ _OptionalDescribeStatementResponseTypeDef = TypedDict(
         "Duration": int,
         "Error": str,
         "HasResultSet": bool,
+        "Id": str,
         "QueryParameters": List["SqlParameterTypeDef"],
         "QueryString": str,
         "RedshiftPid": int,
@@ -95,29 +113,77 @@ _OptionalDescribeStatementResponseTypeDef = TypedDict(
         "SecretArn": str,
         "Status": StatusStringType,
         "UpdatedAt": datetime,
+        "ResponseMetadata": "ResponseMetadataTypeDef",
+    },
+)
+
+_RequiredDescribeTableRequestTypeDef = TypedDict(
+    "_RequiredDescribeTableRequestTypeDef",
+    {
+        "ClusterIdentifier": str,
+        "Database": str,
+    },
+)
+_OptionalDescribeTableRequestTypeDef = TypedDict(
+    "_OptionalDescribeTableRequestTypeDef",
+    {
+        "ConnectedDatabase": str,
+        "DbUser": str,
+        "MaxResults": int,
+        "NextToken": str,
+        "Schema": str,
+        "SecretArn": str,
+        "Table": str,
     },
     total=False,
 )
 
 
-class DescribeStatementResponseTypeDef(
-    _RequiredDescribeStatementResponseTypeDef, _OptionalDescribeStatementResponseTypeDef
+class DescribeTableRequestTypeDef(
+    _RequiredDescribeTableRequestTypeDef, _OptionalDescribeTableRequestTypeDef
 ):
     pass
 
 
-DescribeTableResponseTypeDef = TypedDict(
-    "DescribeTableResponseTypeDef",
+DescribeTableResponseResponseTypeDef = TypedDict(
+    "DescribeTableResponseResponseTypeDef",
     {
         "ColumnList": List["ColumnMetadataTypeDef"],
         "NextToken": str,
         "TableName": str,
+        "ResponseMetadata": "ResponseMetadataTypeDef",
+    },
+)
+
+_RequiredExecuteStatementInputTypeDef = TypedDict(
+    "_RequiredExecuteStatementInputTypeDef",
+    {
+        "ClusterIdentifier": str,
+        "Sql": str,
+    },
+)
+_OptionalExecuteStatementInputTypeDef = TypedDict(
+    "_OptionalExecuteStatementInputTypeDef",
+    {
+        "Database": str,
+        "DbUser": str,
+        "Parameters": List["SqlParameterTypeDef"],
+        "SecretArn": str,
+        "StatementName": str,
+        "WithEvent": bool,
     },
     total=False,
 )
 
-ExecuteStatementOutputTypeDef = TypedDict(
-    "ExecuteStatementOutputTypeDef",
+
+class ExecuteStatementInputTypeDef(
+    _RequiredExecuteStatementInputTypeDef, _OptionalExecuteStatementInputTypeDef
+):
+    pass
+
+
+ExecuteStatementOutputResponseTypeDef = TypedDict(
+    "ExecuteStatementOutputResponseTypeDef",
     {
         "ClusterIdentifier": str,
         "CreatedAt": datetime,
@@ -132,7 +198,7 @@ ExecuteStatementOutputTypeDef = TypedDict(
 FieldTypeDef = TypedDict(
     "FieldTypeDef",
     {
-        "blobValue": Union[bytes, IO[bytes]],
+        "blobValue": bytes,
         "booleanValue": bool,
         "doubleValue": float,
         "isNull": bool,
@@ -142,75 +208,164 @@ FieldTypeDef = TypedDict(
     total=False,
 )
 
-_RequiredGetStatementResultResponseTypeDef = TypedDict(
-    "_RequiredGetStatementResultResponseTypeDef",
+_RequiredGetStatementResultRequestTypeDef = TypedDict(
+    "_RequiredGetStatementResultRequestTypeDef",
     {
-        "Records": List[List["FieldTypeDef"]],
+        "Id": str,
     },
 )
-_OptionalGetStatementResultResponseTypeDef = TypedDict(
-    "_OptionalGetStatementResultResponseTypeDef",
+_OptionalGetStatementResultRequestTypeDef = TypedDict(
+    "_OptionalGetStatementResultRequestTypeDef",
+    {
+        "NextToken": str,
+    },
+    total=False,
+)
+
+
+class GetStatementResultRequestTypeDef(
+    _RequiredGetStatementResultRequestTypeDef, _OptionalGetStatementResultRequestTypeDef
+):
+    pass
+
+
+GetStatementResultResponseResponseTypeDef = TypedDict(
+    "GetStatementResultResponseResponseTypeDef",
     {
         "ColumnMetadata": List["ColumnMetadataTypeDef"],
         "NextToken": str,
+        "Records": List[List["FieldTypeDef"]],
         "TotalNumRows": int,
+        "ResponseMetadata": "ResponseMetadataTypeDef",
+    },
+)
+
+_RequiredListDatabasesRequestTypeDef = TypedDict(
+    "_RequiredListDatabasesRequestTypeDef",
+    {
+        "ClusterIdentifier": str,
+    },
+)
+_OptionalListDatabasesRequestTypeDef = TypedDict(
+    "_OptionalListDatabasesRequestTypeDef",
+    {
+        "Database": str,
+        "DbUser": str,
+        "MaxResults": int,
+        "NextToken": str,
+        "SecretArn": str,
     },
     total=False,
 )
 
 
-class GetStatementResultResponseTypeDef(
-    _RequiredGetStatementResultResponseTypeDef, _OptionalGetStatementResultResponseTypeDef
+class ListDatabasesRequestTypeDef(
+    _RequiredListDatabasesRequestTypeDef, _OptionalListDatabasesRequestTypeDef
 ):
     pass
 
 
-ListDatabasesResponseTypeDef = TypedDict(
-    "ListDatabasesResponseTypeDef",
+ListDatabasesResponseResponseTypeDef = TypedDict(
+    "ListDatabasesResponseResponseTypeDef",
     {
         "Databases": List[str],
         "NextToken": str,
+        "ResponseMetadata": "ResponseMetadataTypeDef",
     },
-    total=False,
 )
 
-ListSchemasResponseTypeDef = TypedDict(
-    "ListSchemasResponseTypeDef",
-    {
-        "NextToken": str,
-        "Schemas": List[str],
-    },
-    total=False,
-)
-
-_RequiredListStatementsResponseTypeDef = TypedDict(
-    "_RequiredListStatementsResponseTypeDef",
-    {
-        "Statements": List["StatementDataTypeDef"],
-    },
-)
-_OptionalListStatementsResponseTypeDef = TypedDict(
-    "_OptionalListStatementsResponseTypeDef",
+_RequiredListSchemasRequestTypeDef = TypedDict(
+    "_RequiredListSchemasRequestTypeDef",
     {
+        "ClusterIdentifier": str,
+        "Database": str,
+    },
+)
+_OptionalListSchemasRequestTypeDef = TypedDict(
+    "_OptionalListSchemasRequestTypeDef",
+    {
+        "ConnectedDatabase": str,
+        "DbUser": str,
+        "MaxResults": int,
         "NextToken": str,
+        "SchemaPattern": str,
+        "SecretArn": str,
     },
     total=False,
 )
 
 
-class ListStatementsResponseTypeDef(
-    _RequiredListStatementsResponseTypeDef, _OptionalListStatementsResponseTypeDef
+class ListSchemasRequestTypeDef(
+    _RequiredListSchemasRequestTypeDef, _OptionalListSchemasRequestTypeDef
 ):
     pass
 
 
-ListTablesResponseTypeDef = TypedDict(
-    "ListTablesResponseTypeDef",
+ListSchemasResponseResponseTypeDef = TypedDict(
+    "ListSchemasResponseResponseTypeDef",
+    {
+        "NextToken": str,
+        "Schemas": List[str],
+        "ResponseMetadata": "ResponseMetadataTypeDef",
+    },
+)
+
+ListStatementsRequestTypeDef = TypedDict(
+    "ListStatementsRequestTypeDef",
+    {
+        "MaxResults": int,
+        "NextToken": str,
+        "RoleLevel": bool,
+        "StatementName": str,
+        "Status": StatusStringType,
+    },
+    total=False,
+)
+
+ListStatementsResponseResponseTypeDef = TypedDict(
+    "ListStatementsResponseResponseTypeDef",
+    {
+        "NextToken": str,
+        "Statements": List["StatementDataTypeDef"],
+        "ResponseMetadata": "ResponseMetadataTypeDef",
+    },
+)
+
+_RequiredListTablesRequestTypeDef = TypedDict(
+    "_RequiredListTablesRequestTypeDef",
+    {
+        "ClusterIdentifier": str,
+        "Database": str,
+    },
+)
+_OptionalListTablesRequestTypeDef = TypedDict(
+    "_OptionalListTablesRequestTypeDef",
+    {
+        "ConnectedDatabase": str,
+        "DbUser": str,
+        "MaxResults": int,
+        "NextToken": str,
+        "SchemaPattern": str,
+        "SecretArn": str,
+        "TablePattern": str,
+    },
+    total=False,
+)
+
+
+class ListTablesRequestTypeDef(
+    _RequiredListTablesRequestTypeDef, _OptionalListTablesRequestTypeDef
+):
+    pass
+
+
+ListTablesResponseResponseTypeDef = TypedDict(
+    "ListTablesResponseResponseTypeDef",
     {
         "NextToken": str,
         "Tables": List["TableMemberTypeDef"],
+        "ResponseMetadata": "ResponseMetadataTypeDef",
     },
-    total=False,
 )
 
 PaginatorConfigTypeDef = TypedDict(
